import {
  Body,
  Controller,
  Delete,
  Post,
  Request,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiBody, ApiOperation, ApiTags } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { Operador } from '../operador/entity/operador.entity';
import { EquipoProgramaService } from './equipo-programa.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { CreateEquipoProgramaDto } from './dto/input/create.dto';
import { DeleteEquipoProgramaDto } from './dto/input/delete.dto';
import { MessageOutputDto } from '../dto/output/message.dto';

@Controller('equipo-programa')
@ApiTags('equipo-programa')
export class EquipoProgramaController {
  constructor(
    private equipoProgramaService: EquipoProgramaService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Serealize(MessageOutputDto)
  @Post()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({ description: 'Asignar un programa a un equipo.' })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Variables que necesita el endpoint.',
    examples: { ejemplo: { value: { id_equipo: 1, id_programa: 1 } } },
  })
  create(@Request() req, @Body() body: CreateEquipoProgramaDto) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarAdminOperador(operador);
    return this.equipoProgramaService.asignar(
      operador,
      body.id_equipo,
      body.id_programa,
    );
  }

  @Serealize(MessageOutputDto)
  @Delete()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Eliminar asociación entre un programa y un equipo.',
  })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Variables que necesita el endpoint.',
    examples: { ejemplo: { value: { id_equipo_programa: 1 } } },
  })
  delete(@Request() req, @Body() body: DeleteEquipoProgramaDto) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarAdminOperador(operador);
    return this.equipoProgramaService.delete(operador, body.id_equipo_programa);
  }
}
