import * as nodemailer from 'nodemailer';
import { Injectable } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';
import { NodemailerMessageDto } from './dto/nodemailer-message.dto';

@Injectable()
export class NodemailerService {
  private transporter;

  constructor(private configService: ConfigService) {
    this.transporter = nodemailer.createTransport({
      service: this.configService.get<string>('NODEMAILER_SERVICE'),
      auth: {
        user: this.configService.get<string>('NODEMAILER_USER'),
        pass: this.configService.get<string>('NODEMAILER_PASWORD'),
      },
    });
  }

  correoPasswordAdmin(operador, password: string) {
    return `<h2>Estimad@ Responsable del programa PC Puma:</h2>
<p>Su registro se ha realizado exitosamente, para acceder al servicio del sistema de préstamo deberá hacerlo con los siguientes datos:</p>

<p>•	Usuario: ${operador}</p>

<p>•	Contraseña: ${password}</p>

<p style=" text-align: justify; text-justify: inter-word;">
  El presente registro le permite tener un uso administrativo del sistema de préstamo de
  dispositivos PC Puma para su entidad. Para acceder al sistema de préstamo es obligatorio y su
  responsabilidad leer y conocer los lineamientos “PC Puma” de la entidad que administra el
  servicio, dichos lineamientos deberán estar ubicados en el módulo de préstamo y en la página de
  su entidad. 
</p>

<p>Para más información o dudas, puede contactarnos por este medio.</p>

<p>Atte.</p>

<p>PC Puma</p>

<p style=" text-align: justify; text-justify: inter-word;">
  <i>
    Hacemos de su conocimiento que la presente información es confidencial y será
    tratada como tal, es de uso exclusivo para el usuario al que fue asignada y se encuentra protegida
    por la normatividad de la Universidad Nacional Autónoma de México en la materia, cualquier uso
    no autorizado o indebido se hará del conocimiento de la autoridad universitaria. Puede consultar
    nuestro aviso de privacidad en: <a href="https://sdi.unam.mx/avisospriv.php" target="_blank">https://sdi.unam.mx/avisospriv.php</a>
  </i>
</p>
  `;
  }

  correoPasswordOperador(operador, password: string) {
    return `<h2>Estimad@ operador del servicio de préstamo PC Puma, su registro se realizó con éxito.</h2>
<p>Para acceder al servicio debe hacerlo con los siguientes datos:</p>

<p>•	Usuario: ${operador}</p>

<p>•	Contraseña: ${password}</p>

<p style=" text-align: justify; text-justify: inter-word;">
  El presente registro le permite hacer uso del sistema de préstamo de dispositivos PC Puma.
  Para acceder al servicio es obligatorio y su responsabilidad leer y conocer los “lineamientos
  PC Puma” de la entidad en la que es solicitado el préstamo, ubicados en el módulo de
  préstamo o la página de su entidad. 
</p>

<p>Para más información o dudas, puede contactarnos por este medio.</p>

<p>Atte.</p>

<p>PC Puma</p>

<p style=" text-align: justify; text-justify: inter-word;">
  <i>
    Hacemos de su conocimiento que la presente
    información es confidencial y será tratada como tal, es de uso exclusivo para el usuario al que
    fue asignada y se encuentra protegida por la normatividad de la Universidad Nacional
    Autónoma de México en la materia, cualquier uso no autorizado o indebido se hará del
    conocimiento de la autoridad universitaria. Puede consultar nuestro aviso de privacidad en:
    <a href="https://sdi.unam.mx/avisospriv.php" target="_blank">https://sdi.unam.mx/avisospriv.php</a>
  </i>
</p>
`;
  }

  correoPasswordUsuario(password: string) {
    return `<h2>Estimad@ usuari@ del servicio de préstamo PC Puma, su registro se realizó con éxito</h2>
<p>Para acceder al servicio debe hacerlo con los siguientes datos:</p>

<p>•	Usuario: Número de cuenta o número de trabajador</p>

<p>•	Contraseña: ${password}</p>

<p style=" text-align: justify; text-justify: inter-word;">
  El presente registro le permite hacer uso del servicio de préstamo de dispositivos PC Puma
  seleccionados, el cual puede ser utilizado únicamente al interior de la entidad donde se solicita el
  servicio. Para acceder al servicio de préstamo es obligatorio y es su responsabilidad leer los
  “lineamientos PC- Puma” de la entidad en la que es solicitado el préstamo, ubicados en el módulo
  de préstamo y en la página de su entidad. El desconocimiento de dichos lineamientos no le exime
  de su responsabilidad y aplicación efectiva de los mismos. 
</p>

<p>Para mayor información o duda contáctenos por este medio.</p>

<p>Atte.</p>

<p>Pc Puma Solicita</p>

<p style=" text-align: justify; text-justify: inter-word;">
  <i>
    Hacemos de su conocimiento que la
    presente información es confidencial y será tratada como tal, es de uso exclusivo para el usuario al
    que fue asignada y se encuentra protegida por la normatividad de la Universidad Nacional
    Autónoma de México en la materia, cualquier uso no autorizado o indebido se hará del
    conocimiento de la autoridad universitaria. Puede consultar nuestro aviso de privacidad en:
    <a href="https://sdi.unam.mx/avisospriv.php" target="_blank">https://sdi.unam.mx/avisospriv.php</a>
  </i>
</p>
`;
  }

  sendEmail(message: NodemailerMessageDto) {
    return this.transporter.sendMail({
      to: message.email,
      subject: message.subject,
      html: message.html,
    });
  }
}
